<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ShapePolygonAFCP</name>
    <message>
        <location filename="../ShapePolygonAFCP.js" line="+61"/>
        <source>Center</source>
        <translation>Środek</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Middle of Side</source>
        <translation>Środek boku</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation>Zrobione</translation>
    </message>
    <message>
        <location filename="../ShapePolygonAFCPInit.js" line="+2"/>
        <source>Pol&amp;ygon (Center, Side)</source>
        <translation>&amp;Wielokąt (środek, bok)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw regular polygon from center and middle point of side</source>
        <translation>Rysuje wielokąt foremny ze środka i punktu środkowego boku</translation>
    </message>
    <message>
        <location filename="../ShapePolygonAFCP.ui" line="+17"/>
        <source>Corners:</source>
        <translation>Liczba narożników:</translation>
    </message>
</context>
</TS>
